summaryrefslogtreecommitdiff
path: root/include/linux/mfd
diff options
context:
space:
mode:
authorJinyoung Park <jinyoungp@nvidia.com>2013-12-11 21:15:25 +0900
committerLaxman Dewangan <ldewangan@nvidia.com>2014-03-04 09:55:02 -0800
commite2c64bcbe0d59e24a812d9dcce99ea9fffc26520 (patch)
tree39c0d173574a2cf639e2d01ee065e2fd423ab3e3 /include/linux/mfd
parent38a16e07b34aca6bf6a551a4faebc4227f56db63 (diff)
iio: staging: adc: palmas: Rename wakeup to auto conversion
Rename wakeup to auto conversion. Bug 1398960 Bug 1415280 Change-Id: I37bee5239caaeec73c7fa6d769b7e9b7476eab9c Signed-off-by: Jinyoung Park <jinyoungp@nvidia.com> (cherry picked from commit 327d973243e1fc6c24002b317a9aac8be24f7748) Reviewed-on: http://git-master/r/357298 Reviewed-by: Anshul Jain (SW) <anshulj@nvidia.com> Tested-by: Anshul Jain (SW) <anshulj@nvidia.com> GVS: Gerrit_Virtual_Submit Reviewed-by: Laxman Dewangan <ldewangan@nvidia.com>
Diffstat (limited to 'include/linux/mfd')
-rw-r--r--include/linux/mfd/palmas.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/linux/mfd/palmas.h b/include/linux/mfd/palmas.h
index 82b1d8276544..c59735e14978 100644
--- a/include/linux/mfd/palmas.h
+++ b/include/linux/mfd/palmas.h
@@ -2,7 +2,7 @@
* TI Palmas
*
* Copyright 2011-2013 Texas Instruments Inc.
- * Copyright (c) 2013, NVIDIA CORPORATION. All rights reserved.
+ * Copyright (c) 2013-2014, NVIDIA CORPORATION. All rights reserved.
*
* Author: Graeme Gregory <gg@slimlogic.co.uk>
* Author: Ian Lartey <ian@slimlogic.co.uk>
@@ -266,12 +266,12 @@ struct palmas {
};
/*
* ADC wakeup property: Wakup the system from suspend when threshold crossed.
* @adc_channel_number: ADC channel number for monitoring.
* @adc_high_threshold: ADC High raw data for upper threshold to generate int.
* @adc_low_threshold: ADC low raw data for lower threshold to generate int.
*/
-struct palmas_adc_wakeup_property {
+struct palmas_adc_auto_conv_property {
int adc_channel_number;
int adc_high_threshold;
int adc_low_threshold;
@@ -297,8 +297,8 @@ struct palmas_gpadc_platform_data {
struct iio_map *iio_maps;
int auto_conversion_period_ms;
- struct palmas_adc_wakeup_property *adc_wakeup1_data;
- struct palmas_adc_wakeup_property *adc_wakeup2_data;
+ struct palmas_adc_auto_conv_property *adc_auto_conv0_data;
+ struct palmas_adc_auto_conv_property *adc_auto_conv1_data;
};
struct palmas_reg_init {
@@ -266,12 +266,12 @@ struct palmas {
};
/*
- * ADC wakeup property: Wakup the system from suspend when threshold crossed.
+ * ADC auto conv property: Generate auto conv interrupt when threshold crossed.
* @adc_channel_number: ADC channel number for monitoring.
* @adc_high_threshold: ADC High raw data for upper threshold to generate int.